==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="uk">
<defaultcodec></defaultcodec>
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Додати файли</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Перегляд списком</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Деталізований перегляд</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Закрити після додавання</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="168"/>
        <source>File name:</source>
        <translation>Ім&apos;я файлу:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="184"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="191"/>
        <source>Files of type:</source>
        <translation>Типи файлів:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="217"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="107"/>
        <source>Qmmp File Dialog</source>
        <translation>Діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="106"/>
        <source>About Qmmp File Dialog</source>
        <translation>Про діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="110"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробники:
Володимир Кузнєцов &lt;vovanec@gmail.com&gt;
Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="111"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Деякий код скопійовано з бібліотеки Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="215"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="228"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="240"/>
        <source>Directories</source>
        <translation>Теки</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="384"/>
        <source>already exists.</source>
        <translation>вже існує.</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="385"/>
        <source>Do you want to replace it?</source>
        <translation>Ви бажаєте замінити?</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Додати файли</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Перегляд списком</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Деталізований перегляд</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Закрити після додавання</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Ім&apos;я файлу:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Типи файлів:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="121"/>
        <location filename="../qmmpfiledialog.cpp" line="130"/>
        <source>Qmmp File Dialog</source>
        <translation>Діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="129"/>
        <source>About Qmmp File Dialog</source>
        <translation>Про діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="131"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробники:
Володимир Кузнєцов &lt;vovanec@gmail.com&gt;
Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="134"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Деякий код скопійовано з бібліотеки Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="272"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="288"/>
        <source>Directories</source>
        <translation>Теки</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
        <source>already exists.</source>
        <translation>вже існує.</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
        <source>Do you want to replace it?</source>
        <translation>Ви бажаєте замінити?</translation>
    </message>
</context>
</TS>
